
# Type: iri type


An IRI

URI: [biolink:IriType](https://w3id.org/biolink/vocab/IriType)

|  |  |  |
| --- | --- | --- |
| Parent type | | [Uriorcurie](types/Uriorcurie.md) |
| Root (builtin) type | | **URIorCURIE** |
| Representation | | str |
